@@ -40,7 +40,9 @@ class AdsApi:
                 log.error(f'Error with {req_info}')
                 raise AdsError(response["msg"])
             log.info(f'Success request to ads {req_info}response = {response}')
-            return response['data']
+            if 'data' in response:
+                return response['data']
+            return response
 
     def query_group(self, page_size: int = 100, group_name: str | None = None, page: int = 1) -> list[dict]:
         resp = self.request(
@@ -106,7 +108,7 @@ class AdsApi:
 
     def delete_account(self, user_ids:list[int]) -> dict:
         resp = self.request('/api/v1/user/delete',
-                            data={'user_ids': user_ids}, method='POST')
+                            json={'user_ids': user_ids}, method='POST')
         return resp
 
 
